bayesianbandits.Bandit
======================

.. currentmodule:: bayesianbandits

.. autoclass:: Bandit

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Bandit.__init__
      ~Bandit.arm
      ~Bandit.decay
      ~Bandit.pull
      ~Bandit.sample
      ~Bandit.update
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Bandit.arms
      ~Bandit.cache
      ~Bandit.last_arm_pulled
      ~Bandit.rng
      ~Bandit.learner
      ~Bandit.policy
   
   